diff PalanthirServer/Internals/MoveScp.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 33d67e1ab173
children
line wrap: on
line diff
--- a/PalanthirServer/Internals/MoveScp.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirServer/Internals/MoveScp.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -24,7 +24,7 @@
 
 #include "../FromDcmtkBridge.h"
 #include "../ToDcmtkBridge.h"
-#include "../../Core/PalantirException.h"
+#include "../../Core/PalanthirException.h"
 
 #include <dcmtk/dcmdata/dcfilefo.h>
 #include <dcmtk/dcmdata/dcmetinf.h>
@@ -33,7 +33,7 @@
 #include <dcmtk/dcmnet/diutil.h>
 
 
-namespace Palantir
+namespace Palanthir
 {
   namespace Internals
   {
@@ -84,7 +84,7 @@
           data.failureCount_ = 0;
           data.warningCount_ = 0;
         }
-        catch (PalantirException& e)
+        catch (PalanthirException& e)
         {
           // Internal error!
           OFLOG_ERROR(Internals::Logger, "IMoveRequestHandler Failed: " << e.What());
@@ -113,7 +113,7 @@
         {
           status = data.iterator_->DoNext();
         }
-        catch (PalantirException& e)
+        catch (PalanthirException& e)
         {
           // Internal error!
           OFLOG_ERROR(Internals::Logger, "IMoveRequestHandler Failed: " << e.What());
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium